@@ -159,6 +159,7 @@ print.gonadMat <- function(x, ...){
 #' the median and the confidece intervals.
 #' @param lwd_hist line with for the vertical line in the histogram.
 #' @param lty_hist line type for the vertical line in the histogram.
+#' @param onlyOgive plot only the ogive.
 #' @param \dots Additional arguments to the plot method.
 #' @examples
 #' data(matFish)
@@ -170,7 +171,8 @@ print.gonadMat <- function(x, ...){
 #' @export
 #' @method plot gonadMat
 plot.gonadMat <- function(x, xlab = "X", ylab = "Proportion mature", col = c("blue", "red"), 
-                        lwd = 2, lty = 2, vline_hist = "black", lwd_hist = 2, lty_hist = 2, ...){
+                        lwd = 2, lty = 2, vline_hist = "black", lwd_hist = 2, lty_hist = 2, 
+                        onlyOgive = FALSE, ...){
   
   if (!inherits(x, "gonadMat"))
     stop("Use only with 'gonadMat' objects")
@@ -185,45 +187,59 @@ plot.gonadMat <- function(x, xlab = "X", ylab = "Proportion mature", col = c("bl
   model1 <- glm(y_input ~ x_input, family = binomial(link = "logit"))
   R2     <- nagelkerkeR2(model1)
   
-  # figure 1
-  hist(x$A_boot, main = "", xlab = "A", col = "grey90")
-  abline(v = as.numeric(quantile(x$A_boot, probs = c(0.5), na.rm = TRUE)), 
-         lwd = lwd_hist, col = vline_hist)
-  abline(v = c(as.numeric(quantile(x$A_boot, probs = c(0.025, 0.975), na.rm = TRUE))), 
-         lty = lty_hist, col = vline_hist)
-  box()
+  if(onlyOgive == TRUE){
+    if(length(col) < 2) stop('col argument must have 2 values. The colors could be the same')
+    if(length(col) > 2) warning('col: only the first two colors will be used in the plot')
+    plot(sort(unique(x_input)), m_p, xlab = xlab, ylab = ylab, pch = 19, col = "darkgrey", ...)
+    lines(sort(x_input), sort(fit$fitted), col = col[1], lwd = lwd)
+    lines(sort(x_input), sort(fit$CIlower), col = col[1], lwd = lwd, lty = lty)
+    lines(sort(x_input), sort(fit$CIupper), col = col[1], lwd = lwd, lty = lty)
+    lines(c(wide[2], wide[2]), c(-1, 0.5), col = col[2], lwd = lwd, lty = lty)
+    lines(c(-1, wide[2]), c(0.5, 0.5), col = col[2], lwd = lwd, lty = lty)
+    points(wide[2], 0.5, pch = 19, col = col[2], cex = 1.25)
+  }else{
+    # figure 1
+    hist(x$A_boot, main = "", xlab = "A", col = "grey90")
+    abline(v = as.numeric(quantile(x$A_boot, probs = c(0.5), na.rm = TRUE)), 
+           lwd = lwd_hist, col = vline_hist)
+    abline(v = c(as.numeric(quantile(x$A_boot, probs = c(0.025, 0.975), na.rm = TRUE))), 
+           lty = lty_hist, col = vline_hist)
+    box()
+    
+    # figure 2
+    hist(x$B_boot, main = "", xlab = "B", col = "grey90")
+    abline(v = as.numeric(quantile(x$B_boot, probs = c(0.5), na.rm = TRUE)), 
+           lwd = lwd_hist, col = vline_hist)
+    abline(v = c(as.numeric(quantile(x$B_boot, probs = c(0.025, 0.975), na.rm = TRUE))), 
+           lty = lty_hist, col = vline_hist)
+    box()
+    
+    # figure 3
+    hist(x$L50_boot, main = "", xlab = "Size at sexual maturity values", col = "grey90")
+    abline(v = as.numeric(quantile(x$L50_boot, probs = c(0.5), na.rm = TRUE)), 
+           lwd = lwd_hist, col = vline_hist)
+    abline(v = c(as.numeric(quantile(x$L50_boot, probs = c(0.025, 0.975), na.rm = TRUE))), 
+           lty = lty_hist, col = vline_hist)
+    box()
+    
+    # figure 4
+    if(length(col) < 2) stop('col argument must have 2 values. The colors could be the same')
+    if(length(col) > 2) warning('col: only the first two colors will be used in the plot')
+    plot(sort(unique(x_input)), m_p, xlab = xlab, ylab = ylab, pch = 19, col = "darkgrey", ...)
+    lines(sort(x_input), sort(fit$fitted), col = col[1], lwd = lwd)
+    lines(sort(x_input), sort(fit$CIlower), col = col[1], lwd = lwd, lty = lty)
+    lines(sort(x_input), sort(fit$CIupper), col = col[1], lwd = lwd, lty = lty)
+    lines(c(wide[2], wide[2]), c(-1, 0.5), col = col[2], lwd = lwd, lty = lty)
+    lines(c(-1, wide[2]), c(0.5, 0.5), col = col[2], lwd = lwd, lty = lty)
+    points(wide[2], 0.5, pch = 19, col = col[2], cex = 1.25)
+    legend("topleft", c(as.expression(bquote(bold(L[50] == .(round(wide[2], 1))))),
+                        as.expression(bquote(bold(R^2 == .(round(R2, 2)))))), 
+           bty = "n")
+  }
   
-  # figure 2
-  hist(x$B_boot, main = "", xlab = "B", col = "grey90")
-  abline(v = as.numeric(quantile(x$B_boot, probs = c(0.5), na.rm = TRUE)), 
-         lwd = lwd_hist, col = vline_hist)
-  abline(v = c(as.numeric(quantile(x$B_boot, probs = c(0.025, 0.975), na.rm = TRUE))), 
-         lty = lty_hist, col = vline_hist)
-  box()
-  
-  # figure 3
-  hist(x$L50_boot, main = "", xlab = "Size at sexual maturity values", col = "grey90")
-  abline(v = as.numeric(quantile(x$L50_boot, probs = c(0.5), na.rm = TRUE)), 
-         lwd = lwd_hist, col = vline_hist)
-  abline(v = c(as.numeric(quantile(x$L50_boot, probs = c(0.025, 0.975), na.rm = TRUE))), 
-         lty = lty_hist, col = vline_hist)
-  box()
-  
-  # figure 4
-  if(length(col) < 2) stop('col argument must have 2 values. The colors could be the same')
-  if(length(col) > 2) warning('col: only the first two colors will be used in the plot')
-  plot(sort(unique(x_input)), m_p, xlab = xlab, ylab = ylab, pch = 19, col = "darkgrey", ...)
-  lines(sort(x_input), sort(fit$fitted), col = col[1], lwd = lwd)
-  lines(sort(x_input), sort(fit$CIlower), col = col[1], lwd = lwd, lty = lty)
-  lines(sort(x_input), sort(fit$CIupper), col = col[1], lwd = lwd, lty = lty)
-  lines(c(wide[2], wide[2]), c(-1, 0.5), col = col[2], lwd = lwd, lty = lty)
-  lines(c(-1, wide[2]), c(0.5, 0.5), col = col[2], lwd = lwd, lty = lty)
-  points(wide[2], 0.5, pch = 19, col = col[2], cex = 1.25)
-  legend("topleft", c(as.expression(bquote(bold(L[50] == .(round(wide[2], 1))))),
-                      as.expression(bquote(bold(R^2 == .(round(R2, 2)))))), 
-         bty = "n")
   cat("Size at gonad maturity =", round(wide[2], 1), "\n")
   cat("Confidence intervals =", round(wide[1], 1), "-",round(wide[3], 1) ,  "\n")
+  cat("Rsquare =", round(R2, 2))
   
   return(invisible(NULL))
 }
